Changelog
=========

0.2 (2014-03-07)
----------------

- Added patch to include custom CSS file for manage and manage_main template.
- Hide 'Add Plone Site' button. Plone sites are created using Chef provisioning
  and collective.recipe.plonesite.


0.1 (2014-03-06)
----------------

- Initial release.
- Added custom view for the Zope root folder ('plone-overview').
